@@ -7,11 +7,12 @@ from mrtopo.translator import c_read, p_read, m_write, desc_write, list_write
 from mrtopo.interpreter import interpret
 from mrtopo.util.filetype import FileType
 from mrtopo.validator.validator import validate
+from mrtopo.tester.tester import test
 import os
 
-__version__ = "0.1.2"
+__version__ = "0.1.6"
 
-def main_routine(args):
+def main_routine(args, number_of_mutations):
 
     log('MrTopo.v.' + __version__ + '>')
 
@@ -40,7 +41,7 @@ def main_routine(args):
             # interpret
             network = interpret(pyfile)
 
-        mutant_networks = mutate(network)
+        mutant_networks = mutate(network, number_of_mutations)
 
         for mutant in mutant_networks:
             m_write(mutant, _file)
@@ -70,3 +71,11 @@ def validate_routine(args, name=None, long=False):
         descriptor.append(validate(_file, name, long))
 
     list_write(descriptor, "validator.txt")
+
+
+def test_routine(dir, target_file, command_file):
+    log('MrTopo.v.' + __version__ + '-tester>')
+
+    results = test(dir, target_file, command_file)
+
+    list_write(results, "MrTopoTest/test.txt")
